@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0050';
+our $VERSION = '0.0051';
 
 use Moo;
 use strictures 2;
@@ -316,7 +316,8 @@ sub import_yaml {
     my $settings = $self->search_settings(name => $patch_name);
 
     if ($settings && @$settings) {
-      print "Removing $patch_name setting from ", $self->model, "\n";
+      print "Removing $patch_name setting from ", $self->model, "\n"
+          if $self->verbose;
       $self->remove_settings(name => $patch_name);
     }
 
@@ -325,7 +326,8 @@ sub import_yaml {
       next unless first { $_ eq $name } @$list;
       for my $set (@{ $patch->{settings} }) {
         my $group = $set->{group};
-        print "Adding $name $group setting to ", $self->model, "\n";
+        print "Adding $name $group setting to ", $self->model, "\n"
+          if $self->verbose;
         $self->make_setting(name => $name, %$set);
       }
     }
@@ -411,7 +413,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0050
+version 0.0051
 
 =head1 SYNOPSIS
 
